@@ -243,7 +243,7 @@ GVApi::doGet(QUrl url, AsyncTaskToken *token, QObject *receiver,
         return false;
     }
 
-    tracker->setAutoRedirect (jar, UA_IPHONE4, true);
+    tracker->setAutoRedirect (jar, true);
     token->apiCtx = tracker;
     token->status = ATTS_SUCCESS;
 
@@ -297,7 +297,7 @@ GVApi::doPost(QUrl url, QByteArray postData, const char *contentType,
         return false;
     }
 
-    tracker->setAutoRedirect (jar, ua, true);
+    tracker->setAutoRedirect (jar, true);
     token->apiCtx = tracker;
     token->status = ATTS_SUCCESS;
 
@@ -933,6 +933,10 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
             task->status = ATTS_AC_NOT_CONFIGURED;
         }
 
+        if (jar) {
+            jar->clearAllCookies ();
+        }
+
         // In all cases, emit completed
         task->emitCompleted ();
     }
