@@ -60,7 +60,12 @@ close $qgvcipfile;
 chomp $cipher;
 $cmd = "perl version.pl __THIS_IS_MY_EXTREMELY_LONG_KEY_ \"$cipher\" qgvdial-$qver";
 print "$cmd\n";
-#system($cmd);
+system($cmd);
+
+# Copy the client secret file to the api directory
+$cmd = "powershell cp ../client_secret_284024172505-2go4p60orvjs7hdmcqpbblh4pr5thu79.apps.googleusercontent.com.json $basedir/api";
+print "$cmd\n";
+system($cmd);
 
 # Mosquitto is merged straight into the build
 $cmd = "cd qgvdial-$qver/qgvdial/symbian & prep_s3_belle.bat";
