@@ -24,12 +24,14 @@ Contact: yuvraaj@gmail.com
 #include "IMainWindow.h"
 #include "ContactsModel.h"
 #include "ContactNumbersModel.h"
+#include "O2ContactsStore.h"
 
 #define GOT_PHOTO_TIMEOUT (3 * 1000)  // 3 seconds
 
 LibContacts::LibContacts(IMainWindow *parent)
 : QObject(parent)
 , m_enableTimerUpdate(false)
+, m_isDownloadingPhoto(false)
 , m_contactsModel(NULL)
 , m_searchedContactsModel(NULL)
 , m_contactPhonesModel(NULL)
@@ -37,10 +39,14 @@ LibContacts::LibContacts(IMainWindow *parent)
 {
     Q_ASSERT(NULL != parent);
 
-    connect (&api, SIGNAL(presentCaptcha(AsyncTaskToken*,QString)),
-             this, SLOT(onPresentCaptcha(AsyncTaskToken*,QString)));
-    connect (&api, SIGNAL(oneContact(ContactInfo)),
-             this, SLOT(onOneContact(ContactInfo)));
+    connect(&api, SIGNAL(presentCaptcha(AsyncTaskToken*,QString)),
+            this, SLOT(onPresentCaptcha(AsyncTaskToken*,QString)));
+    connect(&api, SIGNAL(oneContact(ContactInfo)),
+            this, SLOT(onOneContact(ContactInfo)));
+    connect(&api, SIGNAL(openBrowser(QUrl)),
+            this, SLOT(onOpenBrowser(QUrl)));
+    connect(&api, SIGNAL(closeBrowser()),
+            this, SLOT(onCloseBrowser()));
 
     m_gotPhotoTimer.setSingleShot (true);
     m_gotPhotoTimer.setInterval (GOT_PHOTO_TIMEOUT);
@@ -52,8 +58,15 @@ LibContacts::LibContacts(IMainWindow *parent)
             this, SLOT(refreshLatest()));
 }//LibContacts::LibContacts
 
+void
+LibContacts::init()
+{
+    IMainWindow *win = (IMainWindow *) this->parent ();
+    api.initStore (win->db.createContactsStore ());
+}//LibContacts::init
+
 bool
-LibContacts::login(const QString &user, const QString &pass)
+LibContacts::login(const QString &user)
 {
     AsyncTaskToken *token = new AsyncTaskToken(this);
     if (!token) {
@@ -61,16 +74,44 @@ LibContacts::login(const QString &user, const QString &pass)
         return false;
     }
 
+    Q_DEBUG("Starting contacts login");
+
     connect(token, SIGNAL(completed()),
             this, SLOT(loginCompleted()));
 
     token->inParams["user"] = user;
-    token->inParams["pass"] = pass;
     api.login (token);
 
     return (true);
 }//LibContacts::login
 
+void
+LibContacts::logout()
+{
+    AsyncTaskToken *task = new AsyncTaskToken(this);
+    if (!task) {
+        Q_WARN("Failed to allocate token");
+        return;
+    }
+
+    connect(task, SIGNAL(completed()), task, SLOT(deleteLater()));
+    api.logout (task);
+}//LibContacts::logout
+
+void
+LibContacts::onOpenBrowser(const QUrl &url)
+{
+    IMainWindow *win = (IMainWindow *) this->parent ();
+    win->uiOpenBrowser (url);
+}//LibContacts::onOpenBrowser
+
+void
+LibContacts::onCloseBrowser()
+{
+    IMainWindow *win = (IMainWindow *) this->parent ();
+    win->uiCloseBrowser ();
+}//LibContacts::onCloseBrowser
+
 void
 LibContacts::loginCompleted()
 {
@@ -78,15 +119,14 @@ LibContacts::loginCompleted()
     IMainWindow *win = (IMainWindow *) this->parent ();
 
     if (ATTS_SUCCESS == task->status) {
-        Q_DEBUG("Login successful");
-        win->db.setAppPass (task->inParams["pass"].toString());
-
+        Q_DEBUG("Contacts login successful");
         QDateTime after;
         win->db.getLatestContact (after);
         refresh (after);
     } else {
-        Q_WARN("Login failed");
-        win->uiRequestApplicationPassword ();
+        Q_WARN("Contacts login failed.");
+        win->uiShowMessageBox ("Contacts login has failed.\n"
+                               "Please restart the application");
     }
 
     task->deleteLater ();
@@ -227,27 +267,37 @@ LibContacts::createModel(const QString &query)
 void
 LibContacts::startNextPhoto()
 {
-    if (!m_noPhotos.isEmpty ()) {
-        PhotoLink l = m_noPhotos.takeFirst ();
-        onNoContactPhoto (l.id, l.href);
-    } else {
-        IMainWindow *win = (IMainWindow *) this->parent ();
-        win->uiShowStatusMessage ("Contact photos fetched", SHOW_3SEC);
+    if (m_isDownloadingPhoto) {
+        return;
     }
+
+    bool rv = false;
+    do {
+        if (m_noPhotos.isEmpty()) {
+            IMainWindow *win = (IMainWindow *) this->parent ();
+            win->uiShowStatusMessage ("Contact photos fetched", SHOW_3SEC);
+            break;
+        }
+
+        PhotoLink l = m_noPhotos.takeFirst ();
+        rv = getOnePhoto (l.id, l.href);
+    } while(!rv);
+
+    m_isDownloadingPhoto = rv;
 }//LibContacts::startNextPhoto
 
-void
-LibContacts::onNoContactPhoto(QString contactId, QString photoUrl)
+bool
+LibContacts::getOnePhoto(QString contactId, QString photoUrl)
 {
     if (photoUrl.isEmpty ()) {
         Q_WARN("Empty photo URL");
-        return;
+        return false;
     }
 
     AsyncTaskToken *task = new AsyncTaskToken(this);
     if (NULL == task) {
         Q_WARN("Failed to allocate task to download photo");
-        return;
+        return false;
     }
 
     task->inParams["id"] = contactId;
@@ -257,9 +307,23 @@ LibContacts::onNoContactPhoto(QString contactId, QString photoUrl)
     if (!api.getPhotoFromLink (task)) {
         Q_WARN("Unable to get photo");
         delete task;
+        return false;
     }
 
+    // Dont want the timer running when I start downloading. When the download
+    // completes (success or failure), then I want to start it.
     m_gotPhotoTimer.stop ();
+    return true;
+}//LibContacts::getOnePhoto
+
+void
+LibContacts::onNoContactPhoto(QString contactId, QString photoUrl)
+{
+    PhotoLink l;
+    l.id = contactId;
+    l.href = photoUrl;
+    m_noPhotos.append (l);
+    startNextPhoto ();
 }//LibContacts::onNoContactPhoto
 
 void
@@ -270,10 +334,13 @@ LibContacts::onGotPhoto()
     QString id   = task->inParams["id"].toString();
     QString href = task->inParams["href"].toString();
 
+    bool restartTimer = false;
+
     do {
         if (ATTS_SUCCESS != task->status) {
             Q_WARN(QString("Failed to get photo for ID %1").arg (id));
             win->db.putTempFile (href, UNKNOWN_CONTACT_QRC_PATH);
+            restartTimer = true;
             break;
         }
 
@@ -305,14 +372,17 @@ LibContacts::onGotPhoto()
         tempFile.write (task->outParams["data"].toByteArray());
 
         win->db.putTempFile (href, tempFile.fileName ());
-
-        // Restart the timer only if we have successfully saved the data.
-        m_gotPhotoTimer.stop ();
-        m_gotPhotoTimer.start ();
+        restartTimer = true;
     } while(0);
 
     task->deleteLater ();
 
+    if (restartTimer) {
+        m_gotPhotoTimer.stop ();
+        m_gotPhotoTimer.start ();
+    }
+
+    m_isDownloadingPhoto = false;
     startNextPhoto ();
 }//LibContacts::onGotPhoto
 
