@@ -20,7 +20,7 @@ Contact: yuvraaj@gmail.com
 */
 
 #include "QmlMainWindow.h"
-#include "qmlapplicationviewer.h"
+#include "CQmlViewer.h"
 
 #ifndef UNKNOWN_CONTACT_QRC_PATH
 #error Must define the unknown contact QRC path
@@ -73,7 +73,7 @@ createSingleAppObject(int &argc, char **argv)
 QApplication *
 createNormalAppObject(int &argc, char **argv)
 {
-    Q_ASSERT(USE_SINGLE_APPLICATION);
+    Q_ASSERT(!USE_SINGLE_APPLICATION);
     QApplication *app = createApplication(argc, argv);
     if (NULL == app) {
         Q_WARN("Failed to create QApplication object");
@@ -87,7 +87,7 @@ createNormalAppObject(int &argc, char **argv)
 
 QmlMainWindow::QmlMainWindow(QObject *parent)
 : IMainWindow(parent)
-, m_view(new QmlApplicationViewer)
+, m_view(createQmlViewer())
 , mainPageStack(NULL)
 , mainTabGroup(NULL)
 , loginExpand(NULL)
@@ -95,7 +95,6 @@ QmlMainWindow::QmlMainWindow(QObject *parent)
 , tfaPinDlg(NULL)
 , textUsername(NULL)
 , textPassword(NULL)
-, appPwDlg(NULL)
 , contactsPage(NULL)
 , inboxList(NULL)
 , inboxSelector(NULL)
@@ -113,9 +112,6 @@ QmlMainWindow::QmlMainWindow(QObject *parent)
 , edContactsUpdateFreq(NULL)
 , edInboxUpdateFreq(NULL)
 {
-#if USE_SINGLE_APPLICATION
-    ((QtSingleApplication*)qApp)->setActivationWindow(m_view);
-#endif
 }//QmlMainWindow::QmlMainWindow
 
 QmlMainWindow::~QmlMainWindow()
@@ -129,14 +125,17 @@ QmlMainWindow::~QmlMainWindow()
 void
 QmlMainWindow::init()
 {
+#if USE_SINGLE_APPLICATION
+    ((QtSingleApplication*)qApp)->setActivationWindow(m_view);
+#endif
+
     IMainWindow::init ();
 
-    bool rv =
-    connect(m_view, SIGNAL(statusChanged(QDeclarativeView::Status)),
-            this, SLOT(declStatusChanged(QDeclarativeView::Status)));
+    bool rv = connect(m_view, SIGNAL(viewerStatusChanged(bool)),
+                      this, SLOT(onViewerStatusChanged(bool)));
     Q_ASSERT(rv);
     if (!rv) {
-        Q_WARN("Failed to connect to declStatusChanged signal");
+        Q_WARN("Failed to connect to viewerStatusChanged signal");
         qApp->quit ();
         exit(-1);
         return;
@@ -237,14 +236,18 @@ QmlMainWindow::log(QDateTime /*dt*/, int /*level*/, const QString & /*strLog*/)
 }//QmlMainWindow::log
 
 void
-QmlMainWindow::declStatusChanged(QDeclarativeView::Status status)
+QmlMainWindow::onViewerStatusChanged(bool ready)
 {
-    do {
-        if (QDeclarativeView::Ready != status) {
-            Q_WARN(QString("status = %1").arg (status));
-            break;
-        }
+    if (!initQmlObjects ()) {
+        exit(-1);
+    }
+}//QmlMainWindow::onViewerStatusChanged
 
+bool
+QmlMainWindow::initQmlObjects()
+{
+    bool rv = false;
+    do {
         mainPageStack = getQMLObject ("MainPageStack");
         if (NULL == mainPageStack) {
             break;
@@ -316,12 +319,6 @@ QmlMainWindow::declStatusChanged(QDeclarativeView::Status status)
         connect(inboxSelector, SIGNAL(selectionChanged(QString)),
                 this, SLOT(onInboxSelectionChanged(QString)));
 
-        appPwDlg = getQMLObject ("AppPwDialog");
-        if (NULL == appPwDlg) {
-            break;
-        }
-        connect(appPwDlg, SIGNAL(done(bool)), this, SLOT(onAppPwDlg(bool)));
-
         proxySettingsPage = getQMLObject ("ProxySettingsPage");
         if (NULL == proxySettingsPage) {
             break;
@@ -437,10 +434,10 @@ QmlMainWindow::declStatusChanged(QDeclarativeView::Status status)
                               this, SLOT(onEdInboxUpdateTextChanged()));
 
         onInitDone();
-        return;
+        rv = true;
     } while(0);
-    exit(-1);
-}//QmlMainWindow::declStatusChanged
+    return rv;
+}//QmlMainWindow::initQmlObjects
 
 void
 QmlMainWindow::messageReceived(const QString &msg)
@@ -562,19 +559,17 @@ QmlMainWindow::uiSetUserPass(bool editable)
 }//QmlMainWindow::uiSetUserPass
 
 void
-QmlMainWindow::uiRequestApplicationPassword()
+QmlMainWindow::uiOpenBrowser(const QUrl &url)
 {
-    QMetaObject::invokeMethod (mainPageStack, "pushAppPwDlg");
-}//QmlMainWindow::uiRequestApplicationPassword
+    QMetaObject::invokeMethod (mainPageStack, "showWebPage",
+                               Q_ARG(QVariant, QVariant(url)));
+}//QmlMainWindow::uiOpenBrowser
 
 void
-QmlMainWindow::onAppPwDlg(bool accepted)
+QmlMainWindow::uiCloseBrowser()
 {
-    if (accepted) {
-        QString appPw = appPwDlg->property("appPw").toString();
-        oContacts.login (m_user, appPw);
-    }
-}//QmlMainWindow::onAppPwDlg
+    QMetaObject::invokeMethod (mainPageStack, "hideWebPage");
+}//QmlMainWindow::uiCloseBrowser
 
 void
 QmlMainWindow::uiLoginDone(int status, const QString &errStr)
