@@ -24,7 +24,7 @@ Contact: yuvraaj@gmail.com
 
 #include "IMainWindow.h"
 
-class QmlApplicationViewer;
+class CQmlViewer;
 class QmlMainWindow : public IMainWindow
 {
     Q_OBJECT
@@ -36,7 +36,8 @@ public:
     void log(QDateTime dt, int level, const QString &strLog);
 
 protected slots:
-    void declStatusChanged(QDeclarativeView::Status status);
+    void onViewerStatusChanged(bool ready);
+
     void messageReceived(const QString &msg);
 
     void uiShowStatusMessage(const QString &msg, quint64 millisec);
@@ -45,7 +46,6 @@ protected slots:
 
     void onLoginButtonClicked();
     void onTfaPinDlg(bool accepted);
-    void onAppPwDlg(bool accepted);
 
     void onSigProxyChanges(bool enable, bool useSystemProxy, QString server,
                            int port, bool authRequired, QString user,
@@ -76,11 +76,15 @@ protected:
     bool connectToChangeNotify(QObject *item, const QString &propName,
                                QObject *receiver, const char *slotName);
 
+    bool initQmlObjects();
+
     void uiUpdateProxySettings(const ProxyInfo &info);
     void uiRequestLoginDetails();
     void uiRequestTFALoginDetails(void *ctx);
     void uiSetUserPass(bool editable);
-    void uiRequestApplicationPassword();
+
+    void uiOpenBrowser(const QUrl &url);
+    void uiCloseBrowser();
 
     void uiLoginDone(int status, const QString &errStr);
     void onUserLogoutDone();
@@ -106,7 +110,7 @@ protected:
     void uiSetInboxUpdateFrequency(quint32 mins);
 
 protected:
-    QmlApplicationViewer *m_view;
+    CQmlViewer *m_view;
 
     QObject *mainPageStack;
     QObject *mainTabGroup;
@@ -115,7 +119,6 @@ protected:
     QObject *tfaPinDlg;
     QObject *textUsername;
     QObject *textPassword;
-    QObject *appPwDlg;
     QObject *contactsPage;
     QObject *inboxList;
     QObject *inboxSelector;
